@@ -15,7 +15,7 @@ fi
 host_arch="${DEB_HOST_ARCH:-$(dpkg --print-architecture)}"
 
 if [ -z "${JDK_TO_TEST+x}" ]; then
-  JDK_TO_TEST=$(echo /usr/lib/jvm/java-11-openjdk-amd64 | sed "s/-[^-]*$/-$host_arch/")
+  JDK_TO_TEST=$(echo /usr/lib/jvm/java-17-openjdk-amd64 | sed "s/-[^-]*$/-$host_arch/")
 fi
 
 if [ -z "${BOOTJDK_HOME+x}" ]; then
@@ -45,7 +45,7 @@ if [ ! -x "${BOOTJDK_HOME}/bin/java" ]; then
 fi
 
 # restrict the tests to a few archs (set from debian/rules)
-if ! echo "${host_arch}" | grep -qE "^($(echo amd64 i386 arm64 armhf ppc64 ppc64el sparc64 s390x alpha ia64 powerpc powerpcspe ppc64 sh4 x32 armel mipsel mips64el | tr ' ' '|'))$"; then
+if ! echo "${host_arch}" | grep -qE "^($(echo amd64 i386 arm64 armhf ppc64 ppc64el riscv64 s390x alpha ia64 powerpc ppc64 sh4 x32 armel loong64 mipsel mips64el riscv64 | tr ' ' '|'))$"; then
   echo "Error: ${host_arch} is not on the jtreg_archs list, ignoring it."
   exit 77
 fi
@@ -91,13 +91,13 @@ trap "cleanup" EXIT INT TERM ERR
 jtwork_dir="${AUTOPKGTEST_TMP}/${testsuite}/JTwork"
 output_dir="${AUTOPKGTEST_ARTIFACTS}/${testsuite}/"
 
-# retry tests with "fail" or "error" status at most 2 times
-for i in 0 1 2; do
+# retry tests with "fail" or "error" status at most 3 times
+for i in 0 1; do
   # save each try under its own folder to preserve history
   report_path="${i}/JTreport"
   report_dir="${output_dir}/${report_path}"
   jtreg ${jt_options} \
-    -J-Djtreg.home=/usr/share/jtreg \
+    -vmoption:-Djtreg.home=/usr/share/jtreg \
     -verbose:summary \
     -automatic \
     -retain:none \
@@ -131,8 +131,9 @@ for i in 0 1 2; do
 
   # break if jtdiff reports no difference from previous run
   # also deletes the just created JTreport
-  jtdiff "${output_dir}/JTreport" "$report_dir" >/dev/null 2>&1 \
-    && rm -rf "${report_dir}" && break
+  # DISABLED: don't use it for now as flaky tests could still pass given more retries
+  #jtdiff "${output_dir}/JTreport" "$report_dir" >/dev/null 2>&1 \
+  #  && rm -rf "${report_dir}" && break
 
   # link latest JTreport to output_dir
   ln -sf -t "${output_dir}" "${report_path}"
